class CodeMessageException(Exception):
    def __init__(self, code, message, info=None):
        self.code = code
        self.message = message
        self.info = info

    def __str__(self):
        return repr(self.message)



from setuptools import setup, find_packages

setup(
    name="tea-alpha",
    version="0.0.1",
    keywords=['Exception'],
    license='MIT license',
    author="alphagot812",
    author_email="alphagot@163.com",
    install_requires=[],
    url="https://github.com/alphagot812/tea-alpha",
    packages=find_packages(),
    description="Exception"
)
